.. list-table:: Category: About
   :widths: 15 25
   :header-rows: 1

   * - Endpoint
     - Reason
   * - "/SEMP/v2/config/about"
     - Gives same info as "/SEMP/v2/config/about/api" but has a less specific name.